/**
**************************************************************************
* @file tester_func.h
* @brief Заголовочный файл для функций МЗКТ.
**************************************************************************
@details

*************************************************************************/

	
#ifndef _TESTER_FUNC_H_
#define _TESTER_FUNC_H_

#include "tester_adc_func.h"


typedef struct
{
  GPIO_TypeDef *SW1_Port;
  uint32_t      SW1_Pin;
  
  GPIO_TypeDef *SW2_Port;
  uint32_t      SW2_Pin;
}TESTER_PowerSwitchTypeDef;


typedef struct
{
  unsigned  msdelay:1;
  uint32_t  ticks;
}TESTER_TicksDelayTypeDef;


typedef struct
{
  uint32_t                  msticks_for_positive_dc;
  TESTER_TicksDelayTypeDef  ticks_before_connect;
  TESTER_TicksDelayTypeDef  ticks_before_disconnect;
  TESTER_TicksDelayTypeDef  ticks_before_reconnect;
}TESTER_SwitchTimingsTypeDef;

typedef struct
{
  TESTER_ADCTypeDef *adc;
  
  TESTER_SwitchTimingsTypeDef SwTimings;
  
  TESTER_PowerSwitchTypeDef DCPosSw;
  TESTER_PowerSwitchTypeDef DCNegSw;
  
  uint32_t          continuous_buff_size;
  
  float             DiodeVolt;
}TESTER_TestHandleTypeDef;
extern TESTER_TestHandleTypeDef hTestDiode;



/* Инициализация хендла тестера диодов */
void TESTER_HandleInit(TESTER_TestHandleTypeDef *htest);

/* Тест диодов: подключение прямого напряжения */
void TESTER_TestDiode_PositivePower(TESTER_TestHandleTypeDef *htest);
/* Тест диодов: подключение обратного напряжения */
void TESTER_TestDiode_NegativePower(TESTER_TestHandleTypeDef *htest);
/* Тест диодов: подключение прямого, а потом обратного напряжения */
void TESTER_TestDiode_PosNegPower(TESTER_TestHandleTypeDef *htest);

/* Подключить питание с помощью ключей (пинов) в TESTER_PowerSwitchTypeDef */
void TESTER_Connect_Power(TESTER_PowerSwitchTypeDef *DCSw);
/* Отключить питание с помощью ключей (пинов) в TESTER_PowerSwitchTypeDef */
void TESTER_Disconnect_Power(TESTER_PowerSwitchTypeDef *DCSw);
/* Формирование задержки перед подключением питания (в тиках или миллисекундная) */
void TESTER_Delay(TESTER_TicksDelayTypeDef *tickdelay);
#endif //_TESTER_FUNC_H_

